# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2025-06-22

### Added

- Pagination for both case and party services.

## [0.1.0] - 2025-06-21

### Fixed

- Broken PCLClient class init method.

## [0.0.9] - 2025-06-21

### Added

- Basic logging functionality for services and authentication modules. 

## [0.0.8] - 2025-06-21

### Changed

- Public API structure for Authenticator and PCLClient for clearer/cleaner importing.

## [0.0.7] - 2025-06-20

### Fixed

- Missing default.json file error when installing from PyPI.

## [0.0.6] - 2025-06-20

### Added

- Missing Types documentation.

### Changed

- Client service method names.

## [0.0.5] - 2025-06-19

### Changed

- Documentation hierarchy for a cleaner look.

## [0.0.4] - 2025-06-19

### Changed

- Models to align with XML schema definitions.

## [0.0.3] - 2025-06-18

### Added

- Test suites for remaining modules.

### Removed

- Custom exception classes.

## [0.0.2] - 2025-06-17

### Fixed

- Fixed a bug in the authentication provider that caused issues with multi-factor authentication and redaction argument. 

## [0.0.1] - 2025-06-14

### Added

- Immediate and batched case and party search services.
- Authentication provider with MFA support.
- Sphinx documention.

[0.0.1]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.1
[0.0.2]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.2
[0.0.3]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.3
[0.0.4]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.4
[0.0.5]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.5
[0.0.6]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.6
[0.0.7]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.7
[0.0.8]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.8
[0.0.9]: https://github.com/mcpcpc/pacersdk/releases/tag/0.0.9
[0.1.0]: https://github.com/mcpcpc/pacersdk/releases/tag/0.1.0
[0.1.1]: https://github.com/mcpcpc/pacersdk/releases/tag/0.1.1
